# ConnectME

Prototyping the ConnectME library



## License
ConnectME is licensed under the Apache License 2.0. 

See [LICENSE](https://github.com/gfursin/connectme/blob/master/LICENSE) for more information.

## Support

[Create a GitHub issue](https://github.com/gfursin/connectme/issues/new/choose)
